@@ -62,8 +62,8 @@ class Flag {
 
 };
 
-// --sort=KEY is n/a or by name, score, size, used time, changed time, created time
-enum class Sort { NA, NAME, BEST, SIZE, USED, CHANGED, CREATED };
+// --sort=KEY is n/a or by list, name, score, size, used time, changed time, created time
+enum class Sort { NA, NAME, BEST, SIZE, USED, CHANGED, CREATED, LIST };
 
 // -D, --devices and -d, --directories
 enum class Action { SKIP, READ, RECURSE };
@@ -83,7 +83,7 @@ extern bool flag_files;
 extern bool flag_files_with_matches;
 extern bool flag_files_without_match;
 extern bool flag_fixed_strings;
-extern bool flag_hex_ast;
+extern bool flag_hex_star;
 extern bool flag_hex_cbr;
 extern bool flag_hex_chr;
 extern bool flag_hex_hbr;
@@ -133,6 +133,8 @@ extern Action flag_directories_action;
 extern size_t flag_after_context;
 extern size_t flag_before_context;
 extern size_t flag_fuzzy;
+extern size_t flag_hex_after;
+extern size_t flag_hex_before;
 extern size_t flag_hex_columns;
 extern size_t flag_jobs;
 extern size_t flag_max_count;
